@@ -76,47 +76,6 @@ size_allocate (PanelApplet  *applet,
     drive_list_set_panel_size (drive_list, size);
 }
 
-static void
-change_background (PanelApplet               *applet,
-		   PanelAppletBackgroundType  type,
-		   GdkColor                  *colour,
-		   GdkPixmap                 *pixmap,
-		   DriveList                 *drivelist)
-{
-    GtkRcStyle *rc_style;
-    GtkStyle *style;
-
-    /* reset style */
-    gtk_widget_set_style (GTK_WIDGET (applet), NULL);
-    rc_style = gtk_rc_style_new ();
-    gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-    gtk_rc_style_unref (rc_style);
-
-    switch (type) {
-    case PANEL_NO_BACKGROUND:
-	drive_list_set_transparent (drivelist, FALSE);
-	break;
-
-    case PANEL_COLOR_BACKGROUND:
-	gtk_widget_modify_bg (GTK_WIDGET (applet),
-			      GTK_STATE_NORMAL, colour);
-
-	drive_list_set_transparent (drivelist, TRUE);
-	break;
-
-    case PANEL_PIXMAP_BACKGROUND:
-	style = gtk_style_copy (GTK_WIDGET (applet)->style);
-	if (style->bg_pixmap[GTK_STATE_NORMAL])
-	    g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
-	style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
-	gtk_widget_set_style (GTK_WIDGET (applet), style);
-	g_object_unref (style);
-
-	drive_list_set_transparent (drivelist, TRUE);
-	break;
-    }
-}
-
 static void
 display_about_dialog (BonoboUIComponent *uic,
 		      DriveList *drive_list,
@@ -195,6 +154,7 @@ applet_factory (PanelApplet *applet,
 	panel_applet_add_preferences (applet,
 				      "/schemas/apps/drivemount-applet/prefs",
 				      NULL);
+	panel_applet_set_background_widget (applet, GTK_WIDGET (applet));
 
 	drive_list = drive_list_new ();
 	gtk_container_add (GTK_CONTAINER (applet), drive_list);
@@ -203,8 +163,6 @@ applet_factory (PanelApplet *applet,
 				 G_CALLBACK (change_orient), drive_list, 0);
 	g_signal_connect_object (applet, "size_allocate",
 				 G_CALLBACK (size_allocate), drive_list, 0);
-	g_signal_connect (applet, "change_background",
-			  G_CALLBACK (change_background), drive_list);
 
 	/* set initial state */
 	change_orient (applet,
